@@ -47,16 +47,18 @@ def handle_dict(old_state,new_state,recursion=False):
                     pass
             else:
                 res += "<li>%s:: %s ----> %s</li>" % (key, old_state.get(key, None), new_state.get(key, None))
-    if recursion: return res
+    if recursion or type(new_state) != type({}): return res
     for key in new_state:
-        if key == "_type":
-            if new_state[key] == "datetime":
+        print("Key => ", key)
+        print("new_state => ", new_state)
+        if old_state.get("_type"):
+            if old_state["_type"] == "datetime":
                 if datetime.datetime.strptime(old_state["value"], "%Y-%m-%d %H:%M:%S").strftime(
-                        "%Y-%m-%dT%H:%M:%SZ") != datetime.datetime.strptime(new_state["value"],
+                        "%Y-%m-%dT%H:%M:%SZ") != datetime.datetime.strptime(new_state,
                                                                             "%Y-%m-%d %H:%M:%S").strftime(
                         "%Y-%m-%dT%H:%M:%SZ"):
                     res += "<li> %s ----> %s</li>" % (old_state.get("value"), new_state)
-            elif old_state[key] == "date":
+            elif old_state["_type"] == "date":
                 if datetime.datetime.strptime(old_state["value"], "%Y-%m-%d").strftime("%Y-%m-%d") != new_state:
                     res += "<li> %s ----> %s</li>" % (old_state.get("value"), new_state)
             break
@@ -79,7 +81,7 @@ def handle_dict(old_state,new_state,recursion=False):
 def findChanges(old_state,new_state):
     res="<ul>"
     if type(old_state)==type({}):
-        handle_dict(old_state,new_state)
+        res+=handle_dict(old_state,new_state)
     elif type(old_state)==type([]):
         for key in range(len(old_state)):
             if old_state[key] != get(new_state,key,None):
